##  Obsolescence Risk Statuses of IT Components
The table below lists risk statuses of IT components, from the highest to lowest severity.
Obsolescence Risk Statuses of IT Components Obsolescence Risk Status | Details
---|---
Unaddressed Risk |  This status is assigned to an IT component when the internal end-of-life date or vendor-provided end-of-support date is in the past. ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio389fe81e890242a09b28be3dbb64a38e_LowRes.png) Unaddressed Risk Status
Unaddressed Phase Out |  If the phase-out date is in the past, an IT component always receives the Unaddressed Phase Out status, except when it also qualifies for Unaddressed Risk status. In this case, the Unaddressed Risk status takes precedence because it represents a higher risk. ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe2e578e8d7614bcab6edcd79bb03ac54_LowRes.png) Unaddressed Phase Out Status
Upcoming Risk |  Despite having a vendor-provided end-of-support date in the future, if the internal end-of-life information is not documented, an IT component receives the Upcoming Risk status, provided it doesn’t also qualify for a higher risk status. Lack of internal end-of-life data is not considered as upcoming risk information, as it means it is still active. ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3b250f3216984cab9347d2da0aa75e49_LowRes.png) Upcoming Risk Status
Risk Accepted |  If you mark the Obsolescence Risk Status field on the relation between the IT component and application fact sheet as Risk Accepted, it overrides all other logic, and the IT component is assigned the Risk Accepted status. ![Obsolescence Risk Status Field on the Relation Between IT Component and Application](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27450c917a44101499cb87bbf357eef7_LowRes.png) Obsolescence Risk Status Field on the Relation Between IT Component and Application
Risk Addressed | If you mark the Obsolescence Risk Status field on the relation between the IT component and application fact sheet as Risk Addressed, it overrides all other logic, and the IT component is assigned the Risk Addressed status.
No Risk |  If the vendor-provided end-of-support date is either in the future or not provided, implying the component is still active, and the internal end-of-life date is also in the future, then the IT component is marked as having no risk. Likewise, if you have not documented internal end-of-life and the vendor hasn't provided one—implying it’s still active—then it is assigned the No Risk status. ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio19f85a3fe48b4388a957f135a31711c7_LowRes.png) No Risk Status


